@@ -1,14 +1,22 @@
 """
 Simple interface for progress markers.
 """
-
 from rich.progress import Progress, SpinnerColumn, TimeElapsedColumn
 
+import dascore as dc
+
 
 def track(sequence, description):
     """
     A simple iterator for tracking updates.
     """
+    # This is a dirty hack to allow debugging while running tests.
+    # Otherwise, pdb doesn't work in any tracking scope.
+    # See: https://github.com/Textualize/rich/issues/1053
+    if getattr(dc, "_debug") or not len(sequence):
+        yield from sequence
+        return
+    # Normal progress bar behavior
     progress = Progress(
         SpinnerColumn(),
         *Progress.get_default_columns(),
@@ -19,11 +27,3 @@ def track(sequence, description):
         yield from progress.track(
             sequence, total=total, description=description, update_period=1.0
         )
-
-
-track_index_update = track
-
-
-def dummy_track(iterable, *args, **kwargs):
-    """A dummy tracker for debugging"""
-    return iterable
